@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 execnet
 -------
@@ -7,45 +6,47 @@ pure python lib for connecting to local and remote Python Interpreters.
 
 (c) 2012, Holger Krekel and others
 """
+
 from ._version import version as __version__
-from .deprecated import PopenGateway
-from .deprecated import SocketGateway
-from .deprecated import SshGateway
+from .gateway import Gateway
+from .gateway_base import Channel
 from .gateway_base import DataFormatError
+from .gateway_base import DumpError
+from .gateway_base import LoadError
+from .gateway_base import RemoteError
+from .gateway_base import TimeoutError
 from .gateway_base import dump
 from .gateway_base import dumps
 from .gateway_base import load
 from .gateway_base import loads
-from .gateway_base import RemoteError
-from .gateway_base import TimeoutError
 from .gateway_bootstrap import HostNotFound
-from .multi import default_group
 from .multi import Group
-from .multi import makegateway
 from .multi import MultiChannel
+from .multi import default_group
+from .multi import makegateway
 from .multi import set_execmodel
 from .rsync import RSync
 from .xspec import XSpec
 
-
 __all__ = [
-    "__version__",
-    "PopenGateway",
-    "SocketGateway",
-    "SshGateway",
-    "makegateway",
-    "set_execmodel",
+    "Channel",
+    "DataFormatError",
+    "DumpError",
+    "Gateway",
+    "Group",
     "HostNotFound",
+    "LoadError",
+    "MultiChannel",
+    "RSync",
     "RemoteError",
     "TimeoutError",
     "XSpec",
-    "Group",
-    "MultiChannel",
-    "RSync",
+    "__version__",
     "default_group",
-    "dumps",
-    "loads",
-    "load",
     "dump",
-    "DataFormatError",
+    "dumps",
+    "load",
+    "loads",
+    "makegateway",
+    "set_execmodel",
 ]
